======
GWdama
======

This package aims at providing a unified and easy to use interface to access and manipulate Gravitational Wave data. This can be read from different sources, as in local fram files (``gwf``) ans especially from the `Gravitational Wave Open Science Center <https://www.gw-openscience.org/>`_.

-----------------
Quick start guide
-----------------

GWdama can be installed via `pip <https://docs.python.org/3/installing/index.html>`_,

.. code-block:: console

    $ pip install gwdama

and requires Python 3.6.0 or higher.

It can be readily used from terminal to read and save to disk GW data:
::

    >>> from gwdama.io import GwDataManager

----------------
Package overview
----------------

Sample text
